#[non_exhaustive]pub enum HeaderStyle {
None,
PathArray,
}Expand description
Control what information is retained for individual result documents
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
No information is retained.
PathArray
The path to the child document is retained.
{"a": {"H": 6}, "b": {"H": 7}} would become,
with the default formatter and a target of 1,
{"key":["a"],"value":{"H":6}} and
{"key":["b"],"value":{"H":6}}